Module: ActiveRecord::ConnectionAdapters::Redshift::ColumnMethods
- Included in:
- Table, TableDefinition
- Defined in:
- lib/active_record/connection_adapters/redshift_7_0/schema_definitions.rb,
lib/active_record/connection_adapters/redshift_7_1/schema_definitions.rb,
lib/active_record/connection_adapters/redshift_7_2/schema_definitions.rb,
lib/active_record/connection_adapters/redshift_8_0/schema_definitions.rb
Instance Method Summary collapse
- #json(name, **options) ⇒ Object
- #jsonb(name, **options) ⇒ Object
-
#primary_key(name, type = :primary_key, **options) ⇒ Object
Defines the primary key field.
Instance Method Details
#json(name, **options) ⇒ Object
43 44 45 |
# File 'lib/active_record/connection_adapters/redshift_7_0/schema_definitions.rb', line 43 def json(name, **) column(name, :json, ) end |
#jsonb(name, **options) ⇒ Object
47 48 49 |
# File 'lib/active_record/connection_adapters/redshift_7_0/schema_definitions.rb', line 47 def jsonb(name, **) column(name, :jsonb, ) end |
#primary_key(name, type = :primary_key, **options) ⇒ Object
Defines the primary key field. Use of the native PostgreSQL UUID type is supported, and can be used by defining your tables as such:
create_table :stuffs, id: :uuid do |t|
t.string :content
t.
end
By default, this will use the uuid_generate_v4() function from the uuid-ossp extension, which MUST be enabled on your database. To enable the uuid-ossp extension, you can use the enable_extension method in your migrations. To use a UUID primary key without uuid-ossp enabled, you can set the :default option to nil:
create_table :stuffs, id: false do |t|
t.primary_key :id, :uuid, default: nil
t.uuid :foo_id
t.
end
You may also pass a different UUID generation function from uuid-ossp or another library.
Note that setting the UUID primary key default value to nil will require you to assure that you always provide a UUID value before saving a record (as primary keys cannot be nil). This might be done via the SecureRandom.uuid method and a before_save callback, for instance.
35 36 37 38 39 40 41 |
# File 'lib/active_record/connection_adapters/redshift_7_0/schema_definitions.rb', line 35 def primary_key(name, type = :primary_key, **) return super unless type == :uuid [:default] = .fetch(:default, 'uuid_generate_v4()') [:primary_key] = true column name, type, end |